==> pointpos_api-0.0.5.tar.gz: doc/MerchantAccountApi.md <==
# pointpos_api.api.MerchantAccountApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createMerchantaccount**](MerchantAccountApi.md#createMerchantaccount) | **POST** /merchant | Create Merchantaccount
[**deleteMerchantaccountByID**](MerchantAccountApi.md#deleteMerchantaccountByID) | **DELETE** /merchant/{id} | Delete Merchantaccount By ID
[**findMerchantaccount**](MerchantAccountApi.md#findMerchantaccount) | **GET** /merchant | Get Merchantaccount List
[**getMerchantaccountByID**](MerchantAccountApi.md#getMerchantaccountByID) | **GET** /merchant/{id} | Get Merchantaccount By ID
[**updateMerchantaccountByID**](MerchantAccountApi.md#updateMerchantaccountByID) | **PUT** /merchant/{id} | Update Merchantaccount By ID


# **createMerchantaccount**
> MerchantAccount createMerchantaccount(authorization, xAPIKey, body)

Create Merchantaccount

Create Merchantaccount

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = MerchantAccount(); // MerchantAccount | 

try { 
    var result = api_instance.createMerchantaccount(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling MerchantAccountApi->createMerchantaccount: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**MerchantAccount**](MerchantAccount.md)|  | 

### Return type

[**MerchantAccount**](MerchantAccount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteMerchantaccountByID**
> deleteMerchantaccountByID(authorization, xAPIKey, id)

Delete Merchantaccount By ID

Delete Merchantaccount By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 

try { 
    api_instance.deleteMerchantaccountByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling MerchantAccountApi->deleteMerchantaccountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findMerchantaccount**
> List<MerchantAccount> findMerchantaccount(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Merchantaccount List

Get Merchantaccount  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"personalDetails\"   - \"businessInfo\"   - \"identification\"   - \"publicProfile\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findMerchantaccount(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling MerchantAccountApi->findMerchantaccount: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;personalDetails\&quot;   - \&quot;businessInfo\&quot;   - \&quot;identification\&quot;   - \&quot;publicProfile\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to []]

### Return type

[**List<MerchantAccount>**](MerchantAccount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getMerchantaccountByID**
> MerchantAccount getMerchantaccountByID(authorization, xAPIKey, id)

Get Merchantaccount By ID

Get Merchantaccount By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 

try { 
    var result = api_instance.getMerchantaccountByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling MerchantAccountApi->getMerchantaccountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]

### Return type

[**MerchantAccount**](MerchantAccount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateMerchantaccountByID**
> MerchantAccount updateMerchantaccountByID(authorization, xAPIKey, id, body)

Update Merchantaccount By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('JWT').apiKeyPrefix = 'Bearer';

var api_instance = MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = MerchantAccount(); // MerchantAccount | 

try { 
    var result = api_instance.updateMerchantaccountByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling MerchantAccountApi->updateMerchantaccountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**MerchantAccount**](MerchantAccount.md)|  | 

### Return type

[**MerchantAccount**](MerchantAccount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.0.13.tar.gz: doc/MerchantAccountApi.md <==
# pointpos_api.api.MerchantAccountApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createMerchantaccount**](MerchantAccountApi.md#createMerchantaccount) | **Post** /merchant | Create Merchantaccount
[**deleteMerchantaccountByID**](MerchantAccountApi.md#deleteMerchantaccountByID) | **Delete** /merchant/:id | Delete Merchantaccount By ID
[**findMerchantaccount**](MerchantAccountApi.md#findMerchantaccount) | **Get** /merchant | Get Merchantaccount List
[**getMerchantaccountByID**](MerchantAccountApi.md#getMerchantaccountByID) | **Get** /merchant/:id | Get Merchantaccount By ID
[**updateMerchantaccountByID**](MerchantAccountApi.md#updateMerchantaccountByID) | **Put** /merchant/:id | Update Merchantaccount By ID


# **createMerchantaccount**
> MerchantAccount createMerchantaccount(authorization, xAPIKey, body)

Create Merchantaccount

Create Merchantaccount

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new MerchantAccount(); // MerchantAccount | 

try { 
    var result = api_instance.createMerchantaccount(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling MerchantAccountApi->createMerchantaccount: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**MerchantAccount**](MerchantAccount.md)|  | 

### Return type

[**MerchantAccount**](MerchantAccount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteMerchantaccountByID**
> deleteMerchantaccountByID(authorization, xAPIKey, id)

Delete Merchantaccount By ID

Delete Merchantaccount By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 

try { 
    api_instance.deleteMerchantaccountByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling MerchantAccountApi->deleteMerchantaccountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findMerchantaccount**
> List<MerchantAccount> findMerchantaccount(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Merchantaccount List

Get Merchantaccount  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"personalDetails\"   - \"businessInfo\"   - \"identification\"   - \"publicProfile\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findMerchantaccount(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling MerchantAccountApi->findMerchantaccount: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;personalDetails\&quot;   - \&quot;businessInfo\&quot;   - \&quot;identification\&quot;   - \&quot;publicProfile\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]

### Return type

[**List<MerchantAccount>**](MerchantAccount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getMerchantaccountByID**
> MerchantAccount getMerchantaccountByID(authorization, xAPIKey, id)

Get Merchantaccount By ID

Get Merchantaccount By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 

try { 
    var result = api_instance.getMerchantaccountByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling MerchantAccountApi->getMerchantaccountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]

### Return type

[**MerchantAccount**](MerchantAccount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateMerchantaccountByID**
> MerchantAccount updateMerchantaccountByID(authorization, xAPIKey, id, body)

Update Merchantaccount By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new MerchantAccountApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new MerchantAccount(); // MerchantAccount | 

try { 
    var result = api_instance.updateMerchantaccountByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling MerchantAccountApi->updateMerchantaccountByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**MerchantAccount**](MerchantAccount.md)|  | 

### Return type

[**MerchantAccount**](MerchantAccount.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
